==> haskell-hoauth2-2.14.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.14.0
visibility:           public
id:                   hoauth2-2.14.0-FTm9XpdO6iAFVuCnlMGhxm
key:                  hoauth2-2.14.0-FTm9XpdO6iAFVuCnlMGhxm
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  da1170c5974dd24f2482cfea06afbd08
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.14.0-FTm9XpdO6iAFVuCnlMGhxm
depends:
    aeson-2.1.2.1-6DouAcLayfd1cKsM4PdlxR base-4.18.2.1
    base64-1.0-CbLcJVANRWrDPPKy43i2qu binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-FZect82FX5O86IyFnZ6Ow6
    data-default-0.7.1.3-GjFcYIDEzFPmj8haZ8waF exceptions-0.10.7
    http-conduit-2.3.9.1-GnvZitcVXEVEGsr4Dte5Vr
    http-types-0.12.4-5e6CiUpSQgfFBuPHItSqh0
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 text-2.0.2
    transformers-0.6.1.0 uri-bytestring-0.3.3.1-AHOKB1FBy7T1YX0aVKrKP9
    uri-bytestring-aeson-0.1.0.9-ClBEwxNedlqAtP0Rkq7c7k

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hoauth2-2.14.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.14.0
visibility:           public
id:                   hoauth2-2.14.0-JgAR73NIhlNEQuizV7mZed
key:                  hoauth2-2.14.0-JgAR73NIhlNEQuizV7mZed
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  c417921ba447121d91c72c6c63c34676
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.14.0-JgAR73NIhlNEQuizV7mZed
depends:
    aeson-2.2.0.0-A8FqDK4tVym6hhqwC7qXFC base-4.18.2.1
    base64-1.0-CbLcJVANRWrDPPKy43i2qu binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-FZect82FX5O86IyFnZ6Ow6
    data-default-0.7.1.3-GjFcYIDEzFPmj8haZ8waF exceptions-0.10.7
    http-conduit-2.3.9.1-57yzL8oP4Ah4AluL2Fro4B
    http-types-0.12.4-5e6CiUpSQgfFBuPHItSqh0
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 text-2.0.2
    transformers-0.6.1.0 uri-bytestring-0.3.3.1-AHOKB1FBy7T1YX0aVKrKP9
    uri-bytestring-aeson-0.1.0.9-HDzebawlFPeAgH55ZsvmUG

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
